/*
 * Copyright 2002-2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.cloud.servicebroker.service.events.flows;

import reactor.core.publisher.Mono;

import org.springframework.cloud.servicebroker.model.instance.UpdateServiceInstanceRequest;

/**
 * Error flow for update service instance request
 *
 * @author Roy Clarkson
 */
public interface UpdateServiceInstanceErrorFlow {

	/**
	 * Performs the operation on the error flow
	 *
	 * @param request the service broker request
	 * @param t the error
	 * @return an empty Mono
	 */
	default Mono<Void> error(UpdateServiceInstanceRequest request, Throwable t) {
		return Mono.empty();
	}

}
